@@ -74,6 +74,9 @@ typedef enum
 /* Activating executable text files */
 #define NEMO_PREFERENCES_EXECUTABLE_TEXT_ACTIVATION		"executable-text-activation"
 
+/* Image viewers to pass nemo view sort order to */
+#define NEMO_PREFERENCES_IMAGE_VIEWERS_WITH_EXTERNAL_SORT "image-viewers-with-external-sort"
+
 /* Spatial or browser mode */
 #define NEMO_PREFERENCES_ALWAYS_USE_BROWSER			"always-use-browser"
 #define NEMO_PREFERENCES_NEW_TAB_POSITION			"tabs-open-position"
@@ -111,6 +114,7 @@ typedef enum
 
 /* Sorting order */
 #define NEMO_PREFERENCES_SORT_DIRECTORIES_FIRST		"sort-directories-first"
+#define NEMO_PREFERENCES_SORT_FAVORITES_FIRST		"sort-favorites-first"
 #define NEMO_PREFERENCES_DEFAULT_SORT_ORDER			"default-sort-order"
 #define NEMO_PREFERENCES_DEFAULT_SORT_IN_REVERSE_ORDER	"default-sort-in-reverse-order"
 
@@ -168,7 +172,6 @@ enum
 #define NEMO_PREFERENCES_LIST_VIEW_DEFAULT_ZOOM_LEVEL		"default-zoom-level"
 #define NEMO_PREFERENCES_LIST_VIEW_DEFAULT_VISIBLE_COLUMNS		"default-visible-columns"
 #define NEMO_PREFERENCES_LIST_VIEW_DEFAULT_COLUMN_ORDER		"default-column-order"
-#define NEMO_PREFERENCES_LIST_VIEW_SEARCH_VISIBLE_COLUMNS   "search-visible-columns"
 
 enum
 {
@@ -195,12 +198,6 @@ typedef enum
 #define NEMO_PREFERENCES_IMAGE_FILE_THUMBNAIL_LIMIT	"thumbnail-limit"
 #define NEMO_PREFERENCES_INHERIT_SHOW_THUMBNAILS "inherit-show-thumbnails"
 
-typedef enum
-{
-	NEMO_COMPLEX_SEARCH_BAR,
-	NEMO_SIMPLE_SEARCH_BAR
-} NemoSearchBarMode;
-
 #define NEMO_PREFERENCES_DESKTOP_FONT		   "font"
 #define NEMO_PREFERENCES_DESKTOP_HOME_VISIBLE          "home-icon-visible"
 #define NEMO_PREFERENCES_DESKTOP_COMPUTER_VISIBLE      "computer-icon-visible"
@@ -229,9 +226,10 @@ typedef enum
 
 /* media handling */
 
-#define GNOME_DESKTOP_MEDIA_HANDLING_AUTOMOUNT      "automount"
-#define GNOME_DESKTOP_MEDIA_HANDLING_AUTOMOUNT_OPEN "automount-open"
-#define GNOME_DESKTOP_MEDIA_HANDLING_AUTORUN        "autorun-never"
+#define GNOME_DESKTOP_MEDIA_HANDLING_AUTOMOUNT            "automount"
+#define GNOME_DESKTOP_MEDIA_HANDLING_AUTOMOUNT_OPEN       "automount-open"
+#define GNOME_DESKTOP_MEDIA_HANDLING_AUTORUN              "autorun-never"
+#define NEMO_PREFERENCES_MEDIA_HANDLING_DETECT_CONTENT    "detect-content"
 
 /* Terminal */
 #define GNOME_DESKTOP_TERMINAL_EXEC        "exec"
@@ -261,10 +259,21 @@ typedef enum
 
 #define NEMO_PREFERENCES_CLICK_DOUBLE_PARENT_FOLDER    "click-double-parent-folder"
 
-#define NEMO_PREFERENCES_SAVED_SEARCHES                "saved-searches"
 #define NEMO_PREFERENCES_SHOW_MIME_MAKE_EXECUTABLE     "enable-mime-actions-make-executable"
 #define NEMO_PREFERENCES_DEFERRED_ATTR_PRELOAD_LIMIT   "deferred-attribute-preload-limit"
 
+#define NEMO_PREFERENCES_SEARCH_CONTENT_REGEX          "search-content-use-regex"
+#define NEMO_PREFERENCES_SEARCH_REGEX_FORMAT           "search-regex-format"
+#define NEMO_PREFERENCES_SEARCH_USE_RAW                "search-content-use-raw"
+#define NEMO_PREFERENCES_SEARCH_FILE_CASE              "search-file-case-sensitive"
+#define NEMO_PREFERENCES_SEARCH_CONTENT_CASE           "search-content-case-sensitive"
+#define NEMO_PREFERENCES_SEARCH_SKIP_FOLDERS           "search-skip-folders"
+#define NEMO_PREFERENCES_SEARCH_FILES_RECURSIVELY      "search-files-recursively"
+#define NEMO_PREFERENCES_SEARCH_VISIBLE_COLUMNS        "search-visible-columns"
+#define NEMO_PREFERENCES_SEARCH_FILE_HISTORY           "search-file-history"
+#define NEMO_PREFERENCES_SEARCH_CONTENT_HISTORY        "search-content-history"
+#define NEMO_PREFERENCES_SEARCH_CONTENT_HISTORY_LENGTH "search-content-history-length"
+
 void nemo_global_preferences_init                      (void);
 void nemo_global_preferences_finalize                  (void);
 char *nemo_global_preferences_get_default_folder_viewer_preference_as_iid (void);
@@ -284,8 +293,10 @@ extern GSettings *nemo_compact_view_preferences;
 extern GSettings *nemo_desktop_preferences;
 extern GSettings *nemo_tree_sidebar_preferences;
 extern GSettings *nemo_window_state;
+extern GSettings *gtk_filechooser_preferences;
 extern GSettings *nemo_plugin_preferences;
 extern GSettings *nemo_menu_config_preferences;
+extern GSettings *nemo_search_preferences;
 extern GSettings *gnome_lockdown_preferences;
 extern GSettings *gnome_background_preferences;
 extern GSettings *gnome_media_handling_preferences;
